==> techutils-0.6.0%2B1.21.10-sources.jar: dev/kikugie/techutils/feature/containerscan/verifier/ItemPredicateEntryScreen.java <==
package dev.kikugie.techutils.feature.containerscan.verifier;

import dev.kikugie.techutils.util.ItemPredicateUtils;
import net.minecraft.class_11908;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_333;
import net.minecraft.class_342;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_5244;
import net.minecraft.class_746;
import org.lwjgl.glfw.GLFW;

public class ItemPredicateEntryScreen extends class_437 {
	private static final class_2561 TITLE = class_2561.method_43471("item_predicate_entry_screen.title");
	private static final class_2561 INPUT_TEXT = class_2561.method_43471("item_predicate_entry_screen.input");
	private final class_746 player;
	private class_1799 placeholder;
	private String initInput;
	protected class_342 consoleCommandTextField;
	protected class_4185 doneButton;
	protected class_4185 cancelButton;

	public ItemPredicateEntryScreen(class_746 player) {
		super(class_333.field_18967);
		this.player = player;
	}

	public ItemPredicateEntryScreen(class_746 player, class_1799 placeholder) {
		this(player);
		this.placeholder = placeholder;
	}

	public ItemPredicateEntryScreen(class_746 player, String input) {
		this(player);
		this.initInput = input;
	}

	public ItemPredicateEntryScreen(class_746 player, String input, class_1799 placeholder) {
		this(player, input);
		this.placeholder = placeholder;
	}

	protected void commitAndClose() {
		var stack = ItemPredicateUtils.createPredicateStack(consoleCommandTextField.method_1882(), placeholder);


		int selectedSlot = player.method_31548().method_67532();
		player.method_31548().method_5447(selectedSlot, stack);
		this.field_22787.field_1761.method_2909(stack, 36 + selectedSlot);
		this.player.field_7498.method_7623();

		this.field_22787.method_1507(null);
	}

	@Override
	protected void method_25426() {
		this.doneButton = this.method_37063(
			class_4185.method_46430(class_5244.field_24334, button -> this.commitAndClose()).method_46434(this.field_22789 / 2 - 4 - 150, this.field_22790 / 16 + 120 + 12, 150, 20).method_46431()
		);
		this.cancelButton = this.method_37063(
			class_4185.method_46430(class_5244.field_24335, button -> this.method_25419()).method_46434(this.field_22789 / 2 + 4, this.field_22790 / 16 + 120 + 12, 150, 20).method_46431()
		);
		this.consoleCommandTextField = new class_342(this.field_22793, this.field_22789 / 2 - 150, 50, 300, 20, class_2561.method_43471("advMode.command"));
		this.consoleCommandTextField.method_1880(100000);
		this.consoleCommandTextField.method_1852(initInput);
		this.method_25429(this.consoleCommandTextField);
	}

	@Override
	protected void method_56131() {
		this.method_48265(this.consoleCommandTextField);
	}

	@Override
	public void method_25410(class_310 client, int width, int height) {
		String string = this.consoleCommandTextField.method_1882();
		this.method_25423(client, width, height);
		this.consoleCommandTextField.method_1852(string);
	}

	@Override
	public boolean method_25404(class_11908 input) {
		if (super.method_25404(input)) {
			return true;
		} else if (input.comp_4795() != GLFW.GLFW_KEY_ENTER && input.comp_4795() != GLFW.GLFW_KEY_KP_ENTER) {
			return false;
		} else {
			this.commitAndClose();
			return true;
		}
	}

	@Override
	public void method_25394(class_332 context, int mouseX, int mouseY, float delta) {
		super.method_25394(context, mouseX, mouseY, delta);
		context.method_27534(this.field_22793, TITLE, this.field_22789 / 2, 20, 16777215);
		context.method_27535(this.field_22793, INPUT_TEXT, this.field_22789 / 2 - 150 + 1, 40, 10526880);
		this.consoleCommandTextField.method_25394(context, mouseX, mouseY, delta);
	}

	@Override
	public void method_25420(class_332 context, int mouseX, int mouseY, float delta) {
		this.method_52752(context);
	}
}

==> techutils-0.6.1%2B1.21.7-sources.jar: dev/kikugie/techutils/feature/containerscan/verifier/ItemPredicateEntryScreen.java <==
package dev.kikugie.techutils.feature.containerscan.verifier;

import dev.kikugie.techutils.util.ItemPredicateUtils;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_333;
import net.minecraft.class_342;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_5244;
import net.minecraft.class_746;
import org.lwjgl.glfw.GLFW;

public class ItemPredicateEntryScreen extends class_437 {
	private static final class_2561 TITLE = class_2561.method_43471("item_predicate_entry_screen.title");
	private static final class_2561 INPUT_TEXT = class_2561.method_43471("item_predicate_entry_screen.input");
	private final class_746 player;
	private class_1799 placeholder;
	private String initInput;
	protected class_342 consoleCommandTextField;
	protected class_4185 doneButton;
	protected class_4185 cancelButton;

	public ItemPredicateEntryScreen(class_746 player) {
		super(class_333.field_18967);
		this.player = player;
	}

	public ItemPredicateEntryScreen(class_746 player, class_1799 placeholder) {
		this(player);
		this.placeholder = placeholder;
	}

	public ItemPredicateEntryScreen(class_746 player, String input) {
		this(player);
		this.initInput = input;
	}

	public ItemPredicateEntryScreen(class_746 player, String input, class_1799 placeholder) {
		this(player, input);
		this.placeholder = placeholder;
	}

	protected void commitAndClose() {
		var stack = ItemPredicateUtils.createPredicateStack(consoleCommandTextField.method_1882(), placeholder);


		int selectedSlot = player.method_31548().method_67532();
		player.method_31548().method_5447(selectedSlot, stack);
		this.field_22787.field_1761.method_2909(stack, 36 + selectedSlot);
		this.player.field_7498.method_7623();

		this.field_22787.method_1507(null);
	}

	@Override
	protected void method_25426() {
		this.doneButton = this.method_37063(
			class_4185.method_46430(class_5244.field_24334, button -> this.commitAndClose()).method_46434(this.field_22789 / 2 - 4 - 150, this.field_22790 / 16 + 120 + 12, 150, 20).method_46431()
		);
		this.cancelButton = this.method_37063(
			class_4185.method_46430(class_5244.field_24335, button -> this.method_25419()).method_46434(this.field_22789 / 2 + 4, this.field_22790 / 16 + 120 + 12, 150, 20).method_46431()
		);
		this.consoleCommandTextField = new class_342(this.field_22793, this.field_22789 / 2 - 150, 50, 300, 20, class_2561.method_43471("advMode.command"));
		this.consoleCommandTextField.method_1880(100000);
		this.consoleCommandTextField.method_1852(initInput);
		this.method_25429(this.consoleCommandTextField);
	}

	@Override
	protected void method_56131() {
		this.method_48265(this.consoleCommandTextField);
	}

	@Override
	public void method_25410(class_310 client, int width, int height) {
		String string = this.consoleCommandTextField.method_1882();
		this.method_25423(client, width, height);
		this.consoleCommandTextField.method_1852(string);
	}

	@Override
	public boolean method_25404(int keyCode, int scanCode, int modifiers) {
		if (super.method_25404(keyCode, scanCode, modifiers)) {
			return true;
		} else if (keyCode != GLFW.GLFW_KEY_ENTER && keyCode != GLFW.GLFW_KEY_KP_ENTER) {
			return false;
		} else {
			this.commitAndClose();
			return true;
		}
	}

	@Override
	public void method_25394(class_332 context, int mouseX, int mouseY, float delta) {
		super.method_25394(context, mouseX, mouseY, delta);
		context.method_27534(this.field_22793, TITLE, this.field_22789 / 2, 20, 16777215);
		context.method_27535(this.field_22793, INPUT_TEXT, this.field_22789 / 2 - 150 + 1, 40, 10526880);
		this.consoleCommandTextField.method_25394(context, mouseX, mouseY, delta);
	}

	@Override
	public void method_25420(class_332 context, int mouseX, int mouseY, float delta) {
		this.method_52752(context);
	}
}
